@@ -425,29 +425,31 @@ def constant(x,label=None):
 #----------------------------------------------------------------------------
 def result(un,label=None):
     """
-    Declare an uncertain number to be an intermediate result
-
-    :arg un: an uncertain number or :class:`.UncertainArray`
-    :arg label: a string or sequence of strings
-    
-    When ``un`` is an array, an :class:`.UncertainArray` is returned  
-    containing the intermediate uncertain number objects.
-    
-    .. note::
-    
-        This function does not affect the argument ``un``.
-        Rather, a new intermediate result object is created.
-        So, this function will usually be applied to a temporary object.
-    
-    The component of uncertainty, or the sensitivity, of an uncertain number 
-    with respect to an intermediate result can be evaluated. 
-    
-    Declaring intermediate results also enables the dependencies of uncertain 
-    numbers to be stored in an archive.
+    Create an uncertain number to represent an intermediate result
 
     :arg un: :class:`~lib.UncertainReal` or :class:`~lib.UncertainComplex` or :class:`.UncertainArray`
     :arg label: str or a sequence of str
     :rtype: :class:`~lib.UncertainReal` or :class:`~lib.UncertainComplex` or :class:`.UncertainArray`
+        
+    When ``un`` is an array, an :class:`.UncertainArray` is returned  
+    containing the intermediate uncertain number objects.
+
+    The component of uncertainty, or the sensitivity, of an uncertain number 
+    with respect to an intermediate result can be evaluated. 
+
+    Declaring intermediate results also enables the dependencies of uncertain 
+    numbers to be stored in an archive.
+        
+    .. note::
+    
+        This function will usually be applied to a temporary object.
+
+    .. note::
+    
+        Applying this function to an elementary uncertain number does not create 
+        an intermediate intermediate result. If a label is already assigned to the 
+        elementary uncertain number, it will not be changed and a warning 
+        will be raised, otherwise :func:`~core.result` will assign a label.
     
     **Example**::
 
